@@ -3,18 +3,28 @@
 #include "lc_file.h"
 #include <float.h>
 
-ObjArray<lcColor> gColorList;
+lcArray<lcColor> gColorList;
 lcColorGroup gColorGroups[LC_NUM_COLORGROUPS];
 int gNumUserColors;
 int gEdgeColor;
 int gDefaultColor;
 
+lcVector4 gInterfaceColors[LC_NUM_INTERFACECOLORS] = // todo: make the colors configurable and include the grid and other hardcoded colors here as well.
+{
+	lcVector4(0.898f, 0.298f, 0.400f, 1.000f), // LC_COLOR_SELECTED
+	lcVector4(0.400f, 0.298f, 0.898f, 1.000f), // LC_COLOR_FOCUSED
+	lcVector4(0.500f, 0.800f, 0.500f, 1.000f), // LC_COLOR_CAMERA
+	lcVector4(0.500f, 0.800f, 0.500f, 1.000f), // LC_COLOR_LIGHT
+	lcVector4(0.500f, 0.800f, 0.500f, 0.500f), // LC_COLOR_CONTROL_POINT
+	lcVector4(0.400f, 0.298f, 0.898f, 0.500f)  // LC_COLOR_CONTROL_POINT_FOCUSED
+};
+
 static const char sDefaultColorConfig[] =
 {
 	"0 LDraw.org Configuration File\n"
 	"0 Name: LDConfig.ldr\n"
 	"0 Author: LDraw.org\n"
-	"0 !LDRAW_ORG Configuration UPDATE 2012-09-13\n"
+	"0 !LDRAW_ORG Configuration UPDATE 2013-03-08\n"
 	"\n"
 	"0 // LDraw Solid Colours\n"
 	"0 !COLOUR Black                                                 CODE   0   VALUE #05131D   EDGE #595959\n"
@@ -125,7 +135,7 @@ static const char sDefaultColorConfig[] =
 	"\n"
 	"0 // LDraw Pearl Colours\n"
 	"0 !COLOUR Pearl_White                                           CODE 183   VALUE #F2F3F2   EDGE #333333                               PEARLESCENT\n"
-	"0 !COLOUR Pearl_Very_Light_Grey                                 CODE 150   VALUE #BBBDBC   EDGE #333333                               PEARLESCENT\n"
+	"0 !COLOUR Pearl_Very_Light_Gray                                 CODE 150   VALUE #BBBDBC   EDGE #333333                               PEARLESCENT\n"
 	"0 !COLOUR Pearl_Light_Gray                                      CODE 135   VALUE #9CA3A8   EDGE #333333                               PEARLESCENT\n"
 	"0 !COLOUR Flat_Silver                                           CODE 179   VALUE #898788   EDGE #333333                               PEARLESCENT\n"
 	"0 !COLOUR Pearl_Dark_Gray                                       CODE 148   VALUE #575857   EDGE #333333                               PEARLESCENT\n"
@@ -138,7 +148,7 @@ static const char sDefaultColorConfig[] =
 	"0 // LDraw Metallic Colours\n"
 	"0 !COLOUR Metallic_Silver                                       CODE  80   VALUE #A5A9B4   EDGE #333333                               METAL\n"
 	"0 !COLOUR Metallic_Green                                        CODE  81   VALUE #899B5F   EDGE #333333                               METAL\n"
-	"0 !COLOUR Metallic_Gold                                         CODE  82   VALUE #8C5C20   EDGE #333333                               METAL\n"
+	"0 !COLOUR Metallic_Gold                                         CODE  82   VALUE #DBAC34   EDGE #333333                               METAL\n"
 	"0 !COLOUR Metallic_Black                                        CODE  83   VALUE #1A2831   EDGE #333333                               METAL\n"
 	"0 !COLOUR Metallic_Dark_Gray                                    CODE  87   VALUE #6D6E5C   EDGE #333333                               METAL\n"
 	"\n"
@@ -315,7 +325,7 @@ int lcGetBrickLinkColor(int ColorIndex)
 		{ 115, "Pearl Gold" },
 		{  61, "Pearl Light Gold" },
 		{  66, "Pearl Light Gray" },
-		{ 119, "Pearl Very Light Grey" },           // Pearl Very Light Gray
+		{ 119, "Pearl Very Light Gray" },
 		{  83, "Pearl White" },
 		{  65, "Metallic Gold" },
 		{  70, "Metallic Green" },
@@ -345,7 +355,7 @@ int lcGetBrickLinkColor(int ColorIndex)
 bool lcLoadColorFile(lcFile& File)
 {
 	char Line[1024], Token[1024];
-	ObjArray<lcColor>& Colors = gColorList;
+	lcArray<lcColor>& Colors = gColorList;
 	lcColor Color, MainColor, EdgeColor;
 
 	Colors.RemoveAll();
@@ -353,9 +363,9 @@ bool lcLoadColorFile(lcFile& File)
 	for (int GroupIdx = 0; GroupIdx < LC_NUM_COLORGROUPS; GroupIdx++)
 		gColorGroups[GroupIdx].Colors.RemoveAll();
 
-	strcpy(gColorGroups[0].Name, "Solid Colors");
-	strcpy(gColorGroups[1].Name, "Translucent Colors");
-	strcpy(gColorGroups[2].Name, "Special Colors");
+	gColorGroups[0].Name = QApplication::tr("Solid Colors", "Colors");
+	gColorGroups[1].Name = QApplication::tr("Translucent Colors", "Colors");
+	gColorGroups[2].Name = QApplication::tr("Special Colors", "Colors");
 
 	MainColor.Code = 16;
 	MainColor.Translucent = false;
