@@ -3,8 +3,10 @@
 
 #include <stdio.h>
 #include <string.h>
+#include "lc_math.h"
 
-class String;
+#define LC_FOURCC(ch0, ch1, ch2, ch3) (lcuint32)((lcuint32)(lcuint8)(ch0) | ((lcuint32)(lcuint8)(ch1) << 8) | \
+												((lcuint32)(lcuint8)(ch2) << 16) | ((lcuint32)(lcuint8)(ch3) << 24 ))
 
 class lcFile
 {
@@ -26,11 +28,9 @@ public:
 		WriteBuffer(Buffer, strlen(Buffer));
 	}
 
-	void ReadString(String& Value);
-	void WriteString(const String& Value);
-
-	virtual size_t ReadBuffer(void* Buffer, long Bytes) = 0;
-	virtual size_t WriteBuffer(const void* Buffer, long Bytes) = 0;
+	virtual size_t ReadBuffer(void* Buffer, size_t Bytes) = 0;
+	virtual size_t WriteBuffer(const void* Buffer, size_t Bytes) = 0;
+	virtual void CopyFrom(lcMemFile& Source) = 0;
 
 	lcuint8 ReadU8()
 	{
@@ -147,6 +147,13 @@ public:
 		return Value;
 	}
 
+	lcVector3 ReadVector3()
+	{
+		lcVector3 Vector;
+		ReadFloats(Vector, 3);
+		return Vector;
+	}
+
 	size_t ReadDoubles(double* Buffer, size_t Count)
 	{
 		return Read64(Buffer, Count);
@@ -252,6 +259,11 @@ public:
 		return Write64(Buffer, Count);
 	}
 
+	void WriteVector3(const lcVector3& Vector)
+	{
+		WriteFloats(Vector, 3);
+	}
+
 protected:
 	size_t Read8(void* Buffer, size_t Count)
 	{
@@ -264,7 +276,7 @@ protected:
 
 		NumRead = ReadBuffer(Buffer, Count * 2) / 2;
 
-#ifdef LC_BIG_ENDIAN
+#if Q_BYTE_ORDER == Q_BIG_ENDIAN
 		lcuint8 Temp[2];
 		lcuint8* Bytes = (lcuint8*)Buffer;
 
@@ -287,7 +299,7 @@ protected:
 
 		NumRead = ReadBuffer(Buffer, Count * 4) / 4;
 
-#ifdef LC_BIG_ENDIAN
+#if Q_BYTE_ORDER == Q_BIG_ENDIAN
 		lcuint8 Temp[4];
 		lcuint8* Bytes = (lcuint8*)Buffer;
 
@@ -314,7 +326,7 @@ protected:
 
 		NumRead = ReadBuffer(Buffer, Count * 8) / 8;
 
-#ifdef LC_BIG_ENDIAN
+#if Q_BYTE_ORDER == Q_BIG_ENDIAN
 		lcuint8 Temp[8];
 		lcuint8* Bytes = (lcuint8*)Buffer;
 
@@ -350,7 +362,7 @@ protected:
 
 	size_t Write16(const void* Buffer, size_t Count)
 	{
-#ifdef LC_BIG_ENDIAN
+#if Q_BYTE_ORDER == Q_BIG_ENDIAN
 		size_t BytesWritten = 0;
 		lcuint8 Temp[2];
 		lcuint8* Bytes = (lcuint8*)Buffer;
@@ -371,7 +383,7 @@ protected:
 
 	size_t Write32(const void* Buffer, size_t Count)
 	{
-#ifdef LC_BIG_ENDIAN
+#if Q_BYTE_ORDER == Q_BIG_ENDIAN
 		size_t BytesWritten = 0;
 		lcuint8 Temp[4];
 		lcuint8* Bytes = (lcuint8*)Buffer;
@@ -394,7 +406,7 @@ protected:
 
 	size_t Write64(const void* Buffer, size_t Count)
 	{
-#ifdef LC_BIG_ENDIAN
+#if Q_BYTE_ORDER == Q_BIG_ENDIAN
 		size_t BytesWritten = 0;
 		lcuint8 Temp[8];
 		lcuint8* Bytes = (lcuint8*)Buffer;
@@ -435,10 +447,11 @@ public:
 	void Close();
 
 	char* ReadLine(char* Buffer, size_t BufferSize);
-	size_t ReadBuffer(void* Buffer, long Bytes);
-	size_t WriteBuffer(const void* Buffer, long Bytes);
+	size_t ReadBuffer(void* Buffer, size_t Bytes);
+	size_t WriteBuffer(const void* Buffer, size_t Bytes);
 
 	void CopyFrom(lcFile& Source);
+	void CopyFrom(lcMemFile& Source);
 	void GrowFile(size_t NewLength);
 
 	size_t mGrowBytes;
@@ -463,12 +476,13 @@ public:
 	void Close();
 
 	char* ReadLine(char* Buffer, size_t BufferSize);
-	size_t ReadBuffer(void* Buffer, long Bytes);
-	size_t WriteBuffer(const void* Buffer, long Bytes);
+	size_t ReadBuffer(void* Buffer, size_t Bytes);
+	size_t WriteBuffer(const void* Buffer, size_t Bytes);
 
 	void CopyFrom(lcMemFile& Source);
 
 	bool Open(const char* FileName, const char* Mode);
+	bool Open(const QString& FileName, const char* Mode);
 
 	FILE* mFile;
 };
