@@ -871,6 +871,9 @@ bool lcPiecesLibrary::LoadPiece(PieceInfo* Info)
 	lcLibraryMeshData MeshData;
 	lcArray<lcLibraryTextureMap> TextureStack;
 
+	bool Loaded = false;
+	bool SaveCache = false;
+
 	if (Info->mZipFileType != LC_NUM_ZIPFILES && mZipFiles[Info->mZipFileType])
 	{
 		if (LoadCachePiece(Info))
@@ -878,15 +881,14 @@ bool lcPiecesLibrary::LoadPiece(PieceInfo* Info)
 
 		lcMemFile PieceFile;
 
-		if (!mZipFiles[Info->mZipFileType]->ExtractFile(Info->mZipFileIndex, PieceFile))
-			return false;
+		if (mZipFiles[Info->mZipFileType]->ExtractFile(Info->mZipFileIndex, PieceFile))
+		{
+			const char* OldLocale = setlocale(LC_NUMERIC, "C");
+			Loaded = ReadMeshData(PieceFile, lcMatrix44Identity(), 16, TextureStack, MeshData, LC_MESHDATA_SHARED, true);
+			setlocale(LC_NUMERIC, OldLocale);
+		}
 
-		const char* OldLocale = setlocale(LC_NUMERIC, "C");
-		bool Ret = ReadMeshData(PieceFile, lcMatrix44Identity(), 16, TextureStack, MeshData, LC_MESHDATA_SHARED, true);
-		setlocale(LC_NUMERIC, OldLocale);
-
-        if (!Ret)
-			return false;
+		SaveCache = Loaded && (Info->mZipFileType == LC_ZIPFILE_OFFICIAL);
 	}
 	else
 	{
@@ -899,20 +901,33 @@ bool lcPiecesLibrary::LoadPiece(PieceInfo* Info)
 
 		sprintf(FileName, "%sparts/%s.dat", mLibraryPath, Name);
 
-		if (!PieceFile.Open(FileName, "rt"))
-			return false;
-
-		const char* OldLocale = setlocale(LC_NUMERIC, "C");
-		bool Ret = ReadMeshData(PieceFile, lcMatrix44Identity(), 16, TextureStack, MeshData, LC_MESHDATA_SHARED, true);
-		setlocale(LC_NUMERIC, OldLocale);
-
-        if (!Ret)
-			return false;
+		if (PieceFile.Open(FileName, "rt"))
+		{
+			const char* OldLocale = setlocale(LC_NUMERIC, "C");
+			Loaded = ReadMeshData(PieceFile, lcMatrix44Identity(), 16, TextureStack, MeshData, LC_MESHDATA_SHARED, true);
+			setlocale(LC_NUMERIC, OldLocale);
+		}
 	}
 
+	if (!Loaded && !mCurrentModelPath.isEmpty())
+	{
+		QFileInfo FileInfo(QDir(mCurrentModelPath), Info->m_strName);
+
+		lcDiskFile PieceFile;
+		if (PieceFile.Open(FileInfo.absoluteFilePath().toLatin1().constData(), "rt")) // todo: qstring
+		{
+			const char* OldLocale = setlocale(LC_NUMERIC, "C");
+			Loaded = ReadMeshData(PieceFile, lcMatrix44Identity(), 16, TextureStack, MeshData, LC_MESHDATA_SHARED, false);
+			setlocale(LC_NUMERIC, OldLocale);
+		}
+	}
+
+	if (!Loaded)
+		return false;
+
 	CreateMesh(Info, MeshData);
 
-	if (mZipFiles[LC_ZIPFILE_OFFICIAL])
+	if (SaveCache)
 		SaveCachePiece(Info);
 
 	return true;
@@ -1111,7 +1126,7 @@ lcMesh* lcPiecesLibrary::CreateMesh(PieceInfo* Info, lcLibraryMeshData& MeshData
 				if (MergeSection.Lod)
 				{
 					lcuint32 BaseVertex = DstSection.Texture ? BaseTexturedVertices[LodIdx] : BaseVertices[LodIdx];
-					lcLibraryMeshSection* SrcSection = MergeSection.Shared;
+					lcLibraryMeshSection* SrcSection = MergeSection.Lod;
 
 					for (int IndexIdx = 0; IndexIdx < SrcSection->mIndices.GetSize(); IndexIdx++)
 						*Index++ = BaseVertex + SrcSection->mIndices[IndexIdx];
@@ -1215,6 +1230,9 @@ void lcPiecesLibrary::UpdateBuffers(lcContext* Context)
 		if (!Mesh)
 			continue;
 
+		if (Mesh->mVertexDataSize > 16 * 1024 * 1024 || Mesh->mIndexDataSize > 16 * 1024 * 1024)
+			continue;
+
 		VertexDataSize += Mesh->mVertexDataSize;
 		IndexDataSize += Mesh->mIndexDataSize;
 	}
@@ -1239,6 +1257,9 @@ void lcPiecesLibrary::UpdateBuffers(lcContext* Context)
 		if (!Mesh)
 			continue;
 
+		if (Mesh->mVertexDataSize > 16 * 1024 * 1024 || Mesh->mIndexDataSize > 16 * 1024 * 1024)
+			continue;
+
 		Mesh->mVertexCacheOffset = VertexDataSize;
 		Mesh->mIndexCacheOffset = IndexDataSize;
 
@@ -1544,10 +1565,13 @@ bool lcPiecesLibrary::ReadMeshData(lcFile& File, const lcMatrix44& CurrentTransf
 		{
 		case 1:
 			{
-				char FileName[LC_MAXPATH];
+				char OriginalFileName[LC_MAXPATH];
 				float fm[12];
 
-				sscanf(Line, "%d %i %f %f %f %f %f %f %f %f %f %f %f %f %s", &LineType, &Dummy, &fm[0], &fm[1], &fm[2], &fm[3], &fm[4], &fm[5], &fm[6], &fm[7], &fm[8], &fm[9], &fm[10], &fm[11], FileName);
+				sscanf(Line, "%d %i %f %f %f %f %f %f %f %f %f %f %f %f %s", &LineType, &Dummy, &fm[0], &fm[1], &fm[2], &fm[3], &fm[4], &fm[5], &fm[6], &fm[7], &fm[8], &fm[9], &fm[10], &fm[11], OriginalFileName);
+
+				char FileName[LC_MAXPATH];
+				strcpy(FileName, OriginalFileName);
 
 				char* Ch;
 				for (Ch = FileName; *Ch; Ch++)
@@ -1620,6 +1644,8 @@ bool lcPiecesLibrary::ReadMeshData(lcFile& File, const lcMatrix44& CurrentTransf
 				}
 				else
 				{
+					bool Loaded = false;
+
 					for (int PieceInfoIndex = 0; PieceInfoIndex < mPieces.GetSize(); PieceInfoIndex++)
 					{
 						PieceInfo* Info = mPieces[PieceInfoIndex];
@@ -1631,11 +1657,8 @@ bool lcPiecesLibrary::ReadMeshData(lcFile& File, const lcMatrix44& CurrentTransf
 						{
 							lcMemFile IncludeFile;
 
-							if (!mZipFiles[Info->mZipFileType]->ExtractFile(Info->mZipFileIndex, IncludeFile))
-								break;
-
-							if (!ReadMeshData(IncludeFile, IncludeTransform, ColorCode, TextureStack, MeshData, MeshDataType, Optimize))
-								break;
+							if (mZipFiles[Info->mZipFileType]->ExtractFile(Info->mZipFileIndex, IncludeFile))
+								Loaded = ReadMeshData(IncludeFile, IncludeTransform, ColorCode, TextureStack, MeshData, MeshDataType, Optimize);
 						}
 						else
 						{
@@ -1647,15 +1670,25 @@ bool lcPiecesLibrary::ReadMeshData(lcFile& File, const lcMatrix44& CurrentTransf
 
 							sprintf(FileName, "%sparts/%s.dat", mLibraryPath, Name);
 
-							if (!IncludeFile.Open(FileName, "rt"))
-								break;
-
-							if (!ReadMeshData(IncludeFile, IncludeTransform, ColorCode, TextureStack, MeshData, MeshDataType, Optimize))
-								break;
+							if (IncludeFile.Open(FileName, "rt"))
+								Loaded = ReadMeshData(IncludeFile, IncludeTransform, ColorCode, TextureStack, MeshData, MeshDataType, Optimize);
 						}
 
 						break;
 					}
+
+					if (!Loaded && !mCurrentModelPath.isEmpty())
+					{
+						QFileInfo FileInfo(QDir(mCurrentModelPath), OriginalFileName);
+
+						lcDiskFile IncludeFile;
+						if (IncludeFile.Open(FileInfo.absoluteFilePath().toLatin1().constData(), "rt")) // todo: qstring
+						{
+							const char* OldLocale = setlocale(LC_NUMERIC, "C");
+							Loaded = ReadMeshData(IncludeFile, IncludeTransform, ColorCode, TextureStack, MeshData, MeshDataType, Optimize);
+							setlocale(LC_NUMERIC, OldLocale);
+						}
+					}
 				}
 			} break;
 
@@ -1668,13 +1701,13 @@ bool lcPiecesLibrary::ReadMeshData(lcFile& File, const lcMatrix44& CurrentTransf
 
 				if (TextureMap)
 				{
-					MeshData.AddTexturedLine(MeshDataType, LineType, ColorCode, *TextureMap, Points);
+					MeshData.AddTexturedLine(MeshDataType, LineType, ColorCode, *TextureMap, Points, Optimize);
 
 					if (TextureMap->Next)
 						TextureStack.RemoveIndex(TextureStack.GetSize() - 1);
 				}
 				else
-					MeshData.AddLine(MeshDataType, LineType, ColorCode, Points);
+					MeshData.AddLine(MeshDataType, LineType, ColorCode, Points, Optimize);
 			} break;
 
 		case 3:
@@ -1688,13 +1721,13 @@ bool lcPiecesLibrary::ReadMeshData(lcFile& File, const lcMatrix44& CurrentTransf
 
 				if (TextureMap)
 				{
-					MeshData.AddTexturedLine(MeshDataType, LineType, ColorCode, *TextureMap, Points);
+					MeshData.AddTexturedLine(MeshDataType, LineType, ColorCode, *TextureMap, Points, Optimize);
 
 					if (TextureMap->Next)
 						TextureStack.RemoveIndex(TextureStack.GetSize() - 1);
 				}
 				else
-					MeshData.AddLine(MeshDataType, LineType, ColorCode, Points);
+					MeshData.AddLine(MeshDataType, LineType, ColorCode, Points, Optimize);
 			} break;
 
 		case 4:
@@ -1709,13 +1742,13 @@ bool lcPiecesLibrary::ReadMeshData(lcFile& File, const lcMatrix44& CurrentTransf
 
 				if (TextureMap)
 				{
-					MeshData.AddTexturedLine(MeshDataType, LineType, ColorCode, *TextureMap, Points);
+					MeshData.AddTexturedLine(MeshDataType, LineType, ColorCode, *TextureMap, Points, Optimize);
 
 					if (TextureMap->Next)
 						TextureStack.RemoveIndex(TextureStack.GetSize() - 1);
 				}
 				else
-					MeshData.AddLine(MeshDataType, LineType, ColorCode, Points);
+					MeshData.AddLine(MeshDataType, LineType, ColorCode, Points, Optimize);
 			} break;
 		}
 	}
@@ -1803,7 +1836,7 @@ void lcLibraryMeshData::AddIndices(lcMeshDataType MeshDataType, LC_MESH_PRIMITIV
 	*IndexBuffer = &Indices[CurrentSize];
 }
 
-void lcLibraryMeshData::AddLine(lcMeshDataType MeshDataType, int LineType, lcuint32 ColorCode, const lcVector3* Vertices)
+void lcLibraryMeshData::AddLine(lcMeshDataType MeshDataType, int LineType, lcuint32 ColorCode, const lcVector3* Vertices, bool Optimize)
 {
 	LC_MESH_PRIMITIVE_TYPE PrimitiveType = (LineType == 2) ? LC_MESH_LINES : LC_MESH_TRIANGLES;
 	lcLibraryMeshSection* Section = AddSection(MeshDataType, PrimitiveType, ColorCode, NULL);
@@ -1820,14 +1853,17 @@ void lcLibraryMeshData::AddLine(lcMeshDataType MeshDataType, int LineType, lcuin
 		const lcVector3& Position = Vertices[QuadIndices[IndexIdx]];
 		lcArray<lcVertex>& VertexArray = mVertices[MeshDataType];
 
-		for (int VertexIdx = VertexArray.GetSize() - 1; VertexIdx >= 0; VertexIdx--)
+		if (Optimize)
 		{
-			lcVertex& DstVertex = VertexArray[VertexIdx];
-
-			if (Position == DstVertex.Position)
+			for (int VertexIdx = VertexArray.GetSize() - 1; VertexIdx >= 0; VertexIdx--)
 			{
-				Indices[IndexIdx] = VertexIdx;
-				break;
+				lcVertex& DstVertex = VertexArray[VertexIdx];
+
+				if (Position == DstVertex.Position)
+				{
+					Indices[IndexIdx] = VertexIdx;
+					break;
+				}
 			}
 		}
 
@@ -1867,7 +1903,7 @@ void lcLibraryMeshData::AddLine(lcMeshDataType MeshDataType, int LineType, lcuin
 	}
 }
 
-void lcLibraryMeshData::AddTexturedLine(lcMeshDataType MeshDataType, int LineType, lcuint32 ColorCode, const lcLibraryTextureMap& Map, const lcVector3* Vertices)
+void lcLibraryMeshData::AddTexturedLine(lcMeshDataType MeshDataType, int LineType, lcuint32 ColorCode, const lcLibraryTextureMap& Map, const lcVector3* Vertices, bool Optimize)
 {
 	LC_MESH_PRIMITIVE_TYPE PrimitiveType = (LineType == 2) ? LC_MESH_TEXTURED_LINES : LC_MESH_TEXTURED_TRIANGLES;
 	lcLibraryMeshSection* Section = AddSection(MeshDataType, PrimitiveType, ColorCode, Map.Texture);
@@ -1886,14 +1922,17 @@ void lcLibraryMeshData::AddTexturedLine(lcMeshDataType MeshDataType, int LineTyp
 						   lcDot3(lcVector3(Position.x, Position.y, Position.z), Map.Params[1]) + Map.Params[1].w);
 		lcArray<lcVertexTextured>& VertexArray = mTexturedVertices[MeshDataType];
 
-		for (int VertexIdx = VertexArray.GetSize() - 1; VertexIdx >= 0; VertexIdx--)
+		if (Optimize)
 		{
-			lcVertexTextured& DstVertex = VertexArray[VertexIdx];
-
-			if (Position == DstVertex.Position && TexCoord == DstVertex.TexCoord)
+			for (int VertexIdx = VertexArray.GetSize() - 1; VertexIdx >= 0; VertexIdx--)
 			{
-				Indices[IndexIdx] = VertexIdx;
-				break;
+				lcVertexTextured& DstVertex = VertexArray[VertexIdx];
+
+				if (Position == DstVertex.Position && TexCoord == DstVertex.TexCoord)
+				{
+					Indices[IndexIdx] = VertexIdx;
+					break;
+				}
 			}
 		}
 
@@ -2118,6 +2157,7 @@ void lcLibraryMeshData::AddMeshDataNoDuplicateCheck(const lcLibraryMeshData& Dat
 		{
 			BaseIndex = Vertices.GetSize();
 
+			Vertices.SetGrow(lcMin(Vertices.GetSize(), 8 * 1024 * 1024));
 			Vertices.AllocGrow(DataVertices.GetSize());
 
 			for (int SrcVertexIdx = 0; SrcVertexIdx < DataVertices.GetSize(); SrcVertexIdx++)
@@ -2199,6 +2239,7 @@ void lcLibraryMeshData::AddMeshDataNoDuplicateCheck(const lcLibraryMeshData& Dat
 				Sections.Add(DstSection);
 			}
 
+			DstSection->mIndices.SetGrow(lcMin(DstSection->mIndices.GetSize(), 8 * 1024 * 1024));
 			DstSection->mIndices.AllocGrow(SrcSection->mIndices.GetSize());
 
 			if (!SrcSection->mTexture)
