@@ -8,6 +8,8 @@
 #include "lc_qcolorlist.h"
 #include "lc_qpropertiestree.h"
 #include "lc_qutils.h"
+#include "lc_qupdatedialog.h"
+#include "lc_qaboutdialog.h"
 #include "lc_profile.h"
 #include "preview.h"
 #include "view.h"
@@ -1057,6 +1059,18 @@ void lcMainWindow::Print(QPrinter* Printer)
 	Context->EndRenderToTexture();
 }
 
+void lcMainWindow::ShowUpdatesDialog()
+{
+	lcQUpdateDialog Dialog(this, false);
+	Dialog.exec();
+}
+
+void lcMainWindow::ShowAboutDialog()
+{
+	lcQAboutDialog Dialog(this);
+	Dialog.exec();
+}
+
 void lcMainWindow::ShowPrintDialog()
 {
 	lcModel* Model = lcGetActiveModel();
@@ -1075,41 +1089,21 @@ void lcMainWindow::ShowPrintDialog()
 }
 
 // todo: call dialogs directly
-#include "lc_qimagedialog.h"
 #include "lc_qhtmldialog.h"
-#include "lc_qpovraydialog.h"
 #include "lc_qpropertiesdialog.h"
 #include "lc_qfinddialog.h"
-#include "lc_qselectdialog.h"
-#include "lc_qminifigdialog.h"
-#include "lc_qarraydialog.h"
-#include "lc_qeditgroupsdialog.h"
 #include "lc_qpreferencesdialog.h"
-#include "lc_qupdatedialog.h"
-#include "lc_qaboutdialog.h"
 
 bool lcMainWindow::DoDialog(LC_DIALOG_TYPE Type, void* Data)
 {
 	switch (Type)
 	{
-	case LC_DIALOG_SAVE_IMAGE:
-		{
-			lcQImageDialog Dialog(this, Data);
-			return Dialog.exec() == QDialog::Accepted;
-		} break;
-
 	case LC_DIALOG_EXPORT_HTML:
 		{
 			lcQHTMLDialog Dialog(this, Data);
 			return Dialog.exec() == QDialog::Accepted;
 		} break;
 
-	case LC_DIALOG_EXPORT_POVRAY:
-		{
-			lcQPOVRayDialog Dialog(this, Data);
-			return Dialog.exec() == QDialog::Accepted;
-		} break;
-
 	case LC_DIALOG_PROPERTIES:
 		{
 			lcQPropertiesDialog Dialog(this, Data);
@@ -1122,47 +1116,11 @@ bool lcMainWindow::DoDialog(LC_DIALOG_TYPE Type, void* Data)
 			return Dialog.exec() == QDialog::Accepted;
 		} break;
 
-	case LC_DIALOG_SELECT_BY_NAME:
-		{
-			lcQSelectDialog Dialog(this, Data);
-			return Dialog.exec() == QDialog::Accepted;
-		} break;
-
-	case LC_DIALOG_MINIFIG:
-		{
-			lcQMinifigDialog Dialog(this, Data);
-			return Dialog.exec() == QDialog::Accepted;
-		} break;
-
-	case LC_DIALOG_PIECE_ARRAY:
-		{
-			lcQArrayDialog Dialog(this, Data);
-			return Dialog.exec() == QDialog::Accepted;
-		} break;
-
-	case LC_DIALOG_EDIT_GROUPS:
-		{
-			lcQEditGroupsDialog Dialog(this, Data);
-			return Dialog.exec() == QDialog::Accepted;
-		} break;
-
 	case LC_DIALOG_PREFERENCES:
 		{
 			lcQPreferencesDialog Dialog(this, Data);
 			return Dialog.exec() == QDialog::Accepted;
 		} break;
-
-	case LC_DIALOG_ABOUT:
-		{
-			lcQAboutDialog Dialog(this);
-			return Dialog.exec() == QDialog::Accepted;
-		} break;
-
-	case LC_DIALOG_CHECK_UPDATES:
-		{
-			lcQUpdateDialog Dialog(this, Data);
-			return Dialog.exec() == QDialog::Accepted;
-		} break;
 	}
 
 	return false;
@@ -1373,9 +1331,9 @@ lcVector3 lcMainWindow::GetTransformAmount()
 {
 	lcVector3 Transform;
 
-	Transform.x = mTransformXEdit->text().toFloat();
-	Transform.y = mTransformYEdit->text().toFloat();
-	Transform.z = mTransformZEdit->text().toFloat();
+	Transform.x = lcParseValueLocalized(mTransformXEdit->text());
+	Transform.y = lcParseValueLocalized(mTransformYEdit->text());
+	Transform.z = lcParseValueLocalized(mTransformZEdit->text());
 
 	return Transform;
 }
@@ -1598,10 +1556,7 @@ void lcMainWindow::UpdateSelectedObjects(bool SelectionChanged)
 	}
 	else if (Selection.GetSize() > 0)
 	{
-		if (Selection.GetSize() == 1)
-			Message = tr("1 Object selected");
-		else
-			Message = tr("%1 Objects selected").arg(QString::number(Selection.GetSize()));
+		Message = tr("%n Object(s) selected", "", Selection.GetSize());
 
 		if (Focus && Focus->IsPiece())
 		{
@@ -1618,7 +1573,7 @@ void lcMainWindow::UpdateSelectedObjects(bool SelectionChanged)
 	lcGetActiveModel()->GetFocusPosition(Position);
 
 	QString Label("X: %1 Y: %2 Z: %3");
-	Label = Label.arg(QString::number(Position[0], 'f', 2), QString::number(Position[1], 'f', 2), QString::number(Position[2], 'f', 2));
+	Label = Label.arg(QLocale::system().toString(Position[0], 'f', 2), QLocale::system().toString(Position[1], 'f', 2), QLocale::system().toString(Position[2], 'f', 2));
 	mStatusPositionLabel->setText(Label);
 }
 
@@ -1848,6 +1803,8 @@ void lcMainWindow::NewProject()
 	if (!SaveProjectIfModified())
 		return;
 
+	lcGetPiecesLibrary()->SetCurrentModelPath(QString());
+
 	Project* NewProject = new Project();
 	g_App->SetProject(NewProject);
 	lcGetPiecesLibrary()->UnloadUnusedParts();
@@ -2483,11 +2440,12 @@ void lcMainWindow::HandleCommand(lcCommandId CommandId)
 		break;
 
 	case LC_HELP_UPDATES:
-		DoDialog(LC_DIALOG_CHECK_UPDATES, NULL);
+		ShowUpdatesDialog();
 		break;
 
 	case LC_HELP_ABOUT:
-		DoDialog(LC_DIALOG_ABOUT, NULL);
+		ShowAboutDialog();
+		break;
 
 	case LC_VIEW_TIME_ADD_KEYS:
 		SetAddKeys(!GetAddKeys());
