@@ -17,20 +17,20 @@
 #define LC_RGBA_ALPHA(rgba) ((lcuint8)(((rgba) >> 24) & 0xff))
 #define LC_FLOATRGB(f) LC_RGB(f[0]*255, f[1]*255, f[2]*255)
 
-template <typename T, typename U>
-inline T lcMin(const T& a, const U& b)
+template<typename T>
+inline T lcMin(const T& a, const T& b)
 {
 	return a < b ? a : b;
 }
 
-template <typename T, typename U>
-inline T lcMax(const T& a, const U& b)
+template<typename T>
+inline T lcMax(const T& a, const T& b)
 {
 	return a > b ? a : b;
 }
 
-template <typename T, typename U, typename V>
-inline T lcClamp(const T& Value, const U& Min, const V& Max)
+template<typename T>
+inline T lcClamp(const T& Value, const T& Min, const T& Max)
 {
 	if (Value > Max)
 		return Max;
@@ -92,11 +92,6 @@ public:
 	{
 	}
 
-	lcVector3(const lcVector3& a)
-		: x(a.x), y(a.y), z(a.z)
-	{
-	}
-
 	operator const float*() const
 	{
 		return (const float*)this;
@@ -164,6 +159,47 @@ public:
 	float x, y, z, w;
 };
 
+class lcMatrix33
+{
+public:
+	lcMatrix33()
+	{
+	}
+
+	lcMatrix33(const lcVector3& _x, const lcVector3& _y, const lcVector3& _z)
+	{
+		r[0] = _x;
+		r[1] = _y;
+		r[2] = _z;
+	}
+
+	explicit lcMatrix33(const lcMatrix44& Matrix);
+
+	operator const float*() const
+	{
+		return (const float*)this;
+	}
+	
+	operator float*()
+	{
+		return (float*)this;
+	}
+	
+	const lcVector3& operator[](int i) const
+	{
+		return r[i];
+	}
+
+	lcVector3& operator[](int i)
+	{
+		return r[i];
+	}
+
+	void Orthonormalize();
+
+	lcVector3 r[3];
+};
+
 class lcMatrix44
 {
 public:
@@ -179,6 +215,19 @@ public:
 		r[3] = _w;
 	}
 
+	lcMatrix44(const lcMatrix33& Rotation, const lcVector3& Translation)
+	{
+		r[0] = lcVector4(Rotation[0][0], Rotation[0][1], Rotation[0][2], 0.0f);
+		r[1] = lcVector4(Rotation[1][0], Rotation[1][1], Rotation[1][2], 0.0f);
+		r[2] = lcVector4(Rotation[2][0], Rotation[2][1], Rotation[2][2], 0.0f);
+		r[3] = lcVector4(Translation, 1.0f);
+	}
+
+	lcVector3 GetTranslation() const
+	{
+		return lcVector3(r[3][0], r[3][1], r[3][2]);
+	}
+
 	void SetTranslation(const lcVector3& Translation)
 	{
 		r[3] = lcVector4(Translation[0], Translation[1], Translation[2], 1.0f);
@@ -311,6 +360,20 @@ inline bool operator==(const lcVector3& a, const lcVector3& b)
 	return a.x == b.x && a.y == b.y && a.z == b.z;
 }
 
+inline bool operator!=(const lcVector3& a, const lcVector3& b)
+{
+	return a.x != b.x || a.y != b.y || a.z != b.z;
+}
+
+#ifndef QT_NO_DEBUG
+
+inline QDebug operator<<(QDebug d, const lcVector3& v)
+{
+	return d << v.x << v.y << v.z;
+}
+
+#endif
+
 inline void lcVector3::Normalize()
 {
 	float InvLength = 1.0f / Length();
@@ -385,6 +448,18 @@ inline lcVector3 lcCross(const lcVector3& a, const lcVector3& b)
 	return lcVector3(a.y * b.z - a.z * b.y, a.z * b.x - a.x * b.z, a.x * b.y - a.y * b.x);
 }
 
+template<>
+inline lcVector3 lcMin<lcVector3>(const lcVector3& a, const lcVector3& b)
+{
+	return lcVector3(a.x < b.x ? a.x : b.x, a.y < b.y ? a.y : b.y, a.z < b.z ? a.z : b.z);
+}
+
+template<>
+inline lcVector3 lcMax<lcVector3>(const lcVector3& a, const lcVector3& b)
+{
+	return lcVector3(a.x > b.x ? a.x : b.x, a.y > b.y ? a.y : b.y, a.z > b.z ? a.z : b.z);
+}
+
 inline lcVector4 operator+(const lcVector4& a, const lcVector4& b)
 {
 	return lcVector4(a.x + b.x, a.y + b.y, a.z + b.z, a.w + b.w);
@@ -455,6 +530,11 @@ inline lcVector4& operator/=(lcVector4& a, float b)
 	return a;
 }
 
+inline lcVector3 lcVector3LDrawToLeoCAD(const lcVector3& Vector)
+{
+	return lcVector3(Vector[0], Vector[2], -Vector[1]);
+}
+
 inline lcVector3 lcVector3FromColor(lcuint32 Color)
 {
 	lcVector3 v(LC_RGBA_RED(Color), LC_RGBA_GREEN(Color), LC_RGBA_BLUE(Color));
@@ -474,6 +554,11 @@ inline lcuint32 lcColorFromVector3(const lcVector3& Color)
 	return LC_RGB(Color[0] * 255, Color[1] * 255, Color[2] * 255);
 }
 
+inline lcVector3 lcMul(const lcVector3& a, const lcMatrix33& b)
+{
+	return b.r[0] * a[0] + b.r[1] * a[1] + b.r[2] * a[2];
+}
+
 inline lcVector3 lcMul31(const lcVector3& a, const lcMatrix44& b)
 {
 	lcVector4 v = b.r[0] * a[0] + b.r[1] * a[1] + b.r[2] * a[2] + b.r[3];
@@ -507,19 +592,210 @@ inline lcVector4 lcMul4(const lcVector4& a, const lcMatrix44& b)
 	return b.r[0] * a[0] + b.r[1] * a[1] + b.r[2] * a[2] + b.r[3] * a[3];
 }
 
+inline lcMatrix33 lcMul(const lcMatrix33& a, const lcMatrix33& b)
+{
+	lcVector3 Col0(b.r[0][0], b.r[1][0], b.r[2][0]);
+	lcVector3 Col1(b.r[0][1], b.r[1][1], b.r[2][1]);
+	lcVector3 Col2(b.r[0][2], b.r[1][2], b.r[2][2]);
+
+	lcVector3 Ret0(lcDot(a.r[0], Col0), lcDot(a.r[0], Col1), lcDot(a.r[0], Col2));
+	lcVector3 Ret1(lcDot(a.r[1], Col0), lcDot(a.r[1], Col1), lcDot(a.r[1], Col2));
+	lcVector3 Ret2(lcDot(a.r[2], Col0), lcDot(a.r[2], Col1), lcDot(a.r[2], Col2));
+
+	return lcMatrix33(Ret0, Ret1, Ret2);
+}
+
 inline lcMatrix44 lcMul(const lcMatrix44& a, const lcMatrix44& b)
 {
-	lcVector4 Col0(b.r[0][0], b.r[1][0], b.r[2][0], b.r[3][0]);
-	lcVector4 Col1(b.r[0][1], b.r[1][1], b.r[2][1], b.r[3][1]);
-	lcVector4 Col2(b.r[0][2], b.r[1][2], b.r[2][2], b.r[3][2]);
-	lcVector4 Col3(b.r[0][3], b.r[1][3], b.r[2][3], b.r[3][3]);
+	lcMatrix44 Result;
 
-	lcVector4 Ret0(lcDot(a.r[0], Col0), lcDot(a.r[0], Col1), lcDot(a.r[0], Col2), lcDot(a.r[0], Col3));
-	lcVector4 Ret1(lcDot(a.r[1], Col0), lcDot(a.r[1], Col1), lcDot(a.r[1], Col2), lcDot(a.r[1], Col3));
-	lcVector4 Ret2(lcDot(a.r[2], Col0), lcDot(a.r[2], Col1), lcDot(a.r[2], Col2), lcDot(a.r[2], Col3));
-	lcVector4 Ret3(lcDot(a.r[3], Col0), lcDot(a.r[3], Col1), lcDot(a.r[3], Col2), lcDot(a.r[3], Col3));
+	Result.r[0] = b.r[0] * a[0].x + b.r[1] * a[0].y + b.r[2] * a[0].z + b.r[3] * a[0].w;
+	Result.r[1] = b.r[0] * a[1].x + b.r[1] * a[1].y + b.r[2] * a[1].z + b.r[3] * a[1].w;
+	Result.r[2] = b.r[0] * a[2].x + b.r[1] * a[2].y + b.r[2] * a[2].z + b.r[3] * a[2].w;
+	Result.r[3] = b.r[0] * a[3].x + b.r[1] * a[3].y + b.r[2] * a[3].z + b.r[3] * a[3].w;
 
-	return lcMatrix44(Ret0, Ret1, Ret2, Ret3);
+	return Result;
+}
+
+inline lcMatrix33::lcMatrix33(const lcMatrix44& Matrix)
+{
+	r[0] = lcVector3(Matrix.r[0].x, Matrix.r[0].y, Matrix.r[0].z);
+	r[1] = lcVector3(Matrix.r[1].x, Matrix.r[1].y, Matrix.r[1].z);
+	r[2] = lcVector3(Matrix.r[2].x, Matrix.r[2].y, Matrix.r[2].z);
+}
+
+inline void lcMatrix33::Orthonormalize()
+{
+	r[0] = lcNormalize(r[0]);
+	r[1] = lcNormalize(r[1] - lcDot(r[1], r[0]) * r[0]);
+	r[2] = r[2] - lcDot(r[2], r[0]) * r[0];
+	r[2] -= lcDot(r[2], r[1]) * r[1];
+	r[2] = lcNormalize(r[2]);
+}
+
+inline lcMatrix33 lcMatrix33Identity()
+{
+	lcMatrix33 m;
+
+	m.r[0] = lcVector3(1.0f, 0.0f, 0.0f);
+	m.r[1] = lcVector3(0.0f, 1.0f, 0.0f);
+	m.r[2] = lcVector3(0.0f, 0.0f, 1.0f);
+
+	return m;
+}
+
+inline lcMatrix33 lcMatrix33Scale(const lcVector3& Scale)
+{
+	lcMatrix33 m;
+
+	m.r[0] = lcVector3(Scale.x, 0.0f, 0.0f);
+	m.r[1] = lcVector3(0.0f, Scale.y, 0.0f);
+	m.r[2] = lcVector3(0.0f, 0.0f, Scale.z);
+
+	return m;
+}
+
+inline lcMatrix33 lcMatrix33RotationX(const float Radians)
+{
+	float s, c;
+
+	s = sinf(Radians);
+	c = cosf(Radians);
+
+	lcMatrix33 m;
+
+	m.r[0] = lcVector3(1.0f, 0.0f, 0.0f);
+	m.r[1] = lcVector3(0.0f,    c,    s);
+	m.r[2] = lcVector3(0.0f,   -s,    c);
+
+	return m;
+}
+
+inline lcMatrix33 lcMatrix33RotationY(const float Radians)
+{
+	float s, c;
+
+	s = sinf(Radians);
+	c = cosf(Radians);
+
+	lcMatrix33 m;
+
+	m.r[0] = lcVector3(   c, 0.0f,   -s);
+	m.r[1] = lcVector3(0.0f, 1.0f, 0.0f);
+	m.r[2] = lcVector3(   s, 0.0f,    c);
+
+	return m;
+}
+
+inline lcMatrix33 lcMatrix33RotationZ(const float Radians)
+{
+	float s, c;
+
+	s = sinf(Radians);
+	c = cosf(Radians);
+
+	lcMatrix33 m;
+
+	m.r[0] = lcVector3(   c,    s, 0.0f);
+	m.r[1] = lcVector3(  -s,    c, 0.0f);
+	m.r[2] = lcVector3(0.0f, 0.0f, 1.0f);
+
+	return m;
+}
+
+inline lcMatrix33 lcMatrix33FromAxisAngle(const lcVector3& Axis, const float Radians)
+{
+	float s, c, mag, xx, yy, zz, xy, yz, zx, xs, ys, zs, one_c;
+
+	s = sinf(Radians);
+	c = cosf(Radians);
+	mag = Axis.Length();
+
+	if (mag == 0.0f)
+		return lcMatrix33Identity();
+
+	lcVector3 Normal = Axis * (1.0f / mag);
+
+	xx = Normal[0] * Normal[0];
+	yy = Normal[1] * Normal[1];
+	zz = Normal[2] * Normal[2];
+	xy = Normal[0] * Normal[1];
+	yz = Normal[1] * Normal[2];
+	zx = Normal[2] * Normal[0];
+	xs = Normal[0] * s;
+	ys = Normal[1] * s;
+	zs = Normal[2] * s;
+	one_c = 1.0f - c;
+
+	lcMatrix33 m;
+
+	m.r[0] = lcVector3((one_c * xx) + c, (one_c * xy) + zs, (one_c * zx) - ys);
+	m.r[1] = lcVector3((one_c * xy) - zs, (one_c * yy) + c, (one_c * yz) + xs);
+	m.r[2] = lcVector3((one_c * zx) + ys, (one_c * yz) - xs, (one_c * zz) + c);
+
+	return m;
+}
+
+inline lcMatrix33 lcMatrix33AffineInverse(const lcMatrix33& m)
+{
+	lcMatrix33 Inv;
+
+	Inv.r[0] = lcVector3(m.r[0][0], m.r[1][0], m.r[2][0]);
+	Inv.r[1] = lcVector3(m.r[0][1], m.r[1][1], m.r[2][1]);
+	Inv.r[2] = lcVector3(m.r[0][2], m.r[1][2], m.r[2][2]);
+
+	return Inv;
+}
+
+inline lcMatrix33 lcMatrix33FromEulerAngles(const lcVector3& Radians)
+{
+	float CosYaw, SinYaw, CosPitch, SinPitch, CosRoll, SinRoll;
+
+	CosRoll = cosf(Radians[0]);
+	SinRoll = sinf(Radians[0]);
+	CosPitch = cosf(Radians[1]);
+	SinPitch = sinf(Radians[1]);
+	CosYaw = cosf(Radians[2]);
+	SinYaw = sinf(Radians[2]);
+
+	lcMatrix33 m;
+
+	m.r[0] = lcVector3(CosYaw * CosPitch, SinYaw * CosPitch, -SinPitch);
+	m.r[1] = lcVector3(CosYaw * SinPitch * SinRoll - SinYaw * CosRoll, CosYaw * CosRoll + SinYaw * SinPitch * SinRoll, CosPitch * SinRoll);
+	m.r[2] = lcVector3(CosYaw * SinPitch * CosRoll + SinYaw * SinRoll, SinYaw * SinPitch * CosRoll - CosYaw * SinRoll, CosPitch * CosRoll);
+
+	return m;
+}
+
+inline lcVector3 lcMatrix33ToEulerAngles(const lcMatrix33& RotMat)
+{
+	float SinPitch, CosPitch, SinRoll, CosRoll, SinYaw, CosYaw;
+
+	SinPitch = -RotMat.r[0][2];
+	CosPitch = sqrtf(1 - SinPitch*SinPitch);
+
+	if (fabsf(CosPitch) > 0.0005f)
+	{
+		SinRoll = RotMat.r[1][2] / CosPitch;
+		CosRoll = RotMat.r[2][2] / CosPitch;
+		SinYaw = RotMat.r[0][1] / CosPitch;
+		CosYaw = RotMat.r[0][0] / CosPitch;
+	}
+	else
+	{
+		SinRoll = -RotMat.r[2][1];
+		CosRoll = RotMat.r[1][1];
+		SinYaw = 0.0f;
+		CosYaw = 1.0f;
+	}
+
+	lcVector3 Rot(atan2f(SinRoll, CosRoll), atan2f(SinPitch, CosPitch), atan2f(SinYaw, CosYaw));
+
+	if (Rot[0] < 0) Rot[0] += LC_2PI;
+	if (Rot[1] < 0) Rot[1] += LC_2PI;
+	if (Rot[2] < 0) Rot[2] += LC_2PI;
+
+	return Rot;
 }
 
 inline lcMatrix44 lcMatrix44Identity()
@@ -597,6 +873,18 @@ inline lcMatrix44 lcMatrix44RotationZ(const float Radians)
 	return m;
 }
 
+inline lcMatrix44 lcMatrix44Scale(const lcVector3& Scale)
+{
+	lcMatrix44 m;
+
+	m.r[0] = lcVector4(Scale.x, 0.0f, 0.0f, 0.0f);
+	m.r[1] = lcVector4(0.0f, Scale.y, 0.0f, 0.0f);
+	m.r[2] = lcVector4(0.0f, 0.0f, Scale.z, 0.0f);
+	m.r[3] = lcVector4(0.0f, 0.0f, 0.0f, 1.0f);
+
+	return m;
+}
+
 inline lcMatrix44 lcMatrix44LookAt(const lcVector3& Eye, const lcVector3& Target, const lcVector3& Up)
 {
 	lcVector3 x, y, z;
@@ -979,6 +1267,30 @@ inline lcMatrix44 lcMatrix44Inverse(const lcMatrix44& m)
 #undef SWAP_ROWS
 }
 
+inline lcMatrix44 lcMatrix44LeoCADToLDraw(const lcMatrix44& Matrix)
+{
+	lcMatrix44 m;
+
+	m.r[0] = lcVector4(Matrix[0][0], -Matrix[2][0], Matrix[1][0], 0.0f);
+	m.r[1] = lcVector4(-Matrix[0][2], Matrix[2][2], -Matrix[1][2], 0.0f);
+	m.r[2] = lcVector4(Matrix[0][1], -Matrix[2][1], Matrix[1][1], 0.0f);
+	m.r[3] = lcVector4(Matrix[3][0], -Matrix[3][2], Matrix[3][1], 1.0f);
+
+	return m;
+}
+
+inline lcMatrix44 lcMatrix44LDrawToLeoCAD(const lcMatrix44& Matrix)
+{
+	lcMatrix44 m;
+
+	m.r[0] = lcVector4(Matrix[0][0], Matrix[2][0], -Matrix[1][0], 0.0f);
+	m.r[1] = lcVector4(Matrix[0][2], Matrix[2][2], -Matrix[1][2], 0.0f);
+	m.r[2] = lcVector4(-Matrix[0][1], -Matrix[2][1], Matrix[1][1], 0.0f);
+	m.r[3] = lcVector4(Matrix[3][0], Matrix[3][2], -Matrix[3][1], 1.0f);
+
+	return m;
+}
+
 inline lcVector4 lcQuaternionRotationX(float Radians)
 {
 	return lcVector4(sinf(Radians / 2.0f), 0, 0, cosf(Radians / 2.0f));
@@ -1178,6 +1490,38 @@ inline lcVector3 lcZoomExtents(const lcVector3& Position, const lcMatrix44& Worl
 	return Position - (Front * SmallestDistance);
 }
 
+inline void lcClosestPointsBetweenLines(const lcVector3& Line1a, const lcVector3& Line1b, const lcVector3& Line2a, const lcVector3& Line2b, lcVector3* Intersection1, lcVector3* Intersection2)
+{
+	lcVector3 u1 = Line1b - Line1a;
+	lcVector3 u2 = Line2b - Line2a;
+	lcVector3 p21 = Line2a - Line1a;
+	lcVector3 m = lcCross(u2, u1);
+	float m2 = lcDot(m, m);
+
+	if (m2 < 0.00001f)
+	{
+		if (Intersection1)
+			*Intersection1 = Line1a;
+		if (Intersection2)
+			*Intersection2 = Line2a;
+		return;
+	}
+
+	lcVector3 r = lcCross(p21, m / m2);
+
+	if (Intersection1)
+	{
+		float t1 = lcDot(r, u2);
+		*Intersection1 = Line1a + t1 * u1;
+	}
+
+	if (Intersection2)
+	{
+		float t2 = lcDot(r, u1);
+		*Intersection2 = Line2a + t2 * u2;
+	}
+}
+
 // Calculate the intersection of a line segment and a plane and returns false
 // if they are parallel or the intersection is outside the line segment.
 inline bool lcLinePlaneIntersection(lcVector3* Intersection, const lcVector3& Start, const lcVector3& End, const lcVector4& Plane)
@@ -1350,7 +1694,7 @@ inline bool lcTriangleIntersectsPlanes(float* p1, float* p2, float* p3, const lc
 }
 
 // Return true if a ray intersects a bounding box, and calculates the distance from the start of the ray (adapted from Graphics Gems).
-inline bool lcBoundingBoxRayMinIntersectDistance(const lcVector3& Min, const lcVector3& Max, const lcVector3& Start, const lcVector3& End, float* Dist, lcVector3* Intersection)
+inline bool lcBoundingBoxRayIntersectDistance(const lcVector3& Min, const lcVector3& Max, const lcVector3& Start, const lcVector3& End, float* Dist, lcVector3* Intersection)
 {
 	bool MiddleQuadrant[3];
 	bool Inside = true;
@@ -1465,26 +1809,19 @@ inline bool lcSphereRayMinIntersectDistance(const lcVector3& Center, float Radiu
 	}
 }
 
-/*
-float LinePointMinDistance(const Vector3& Point, const Vector3& Start, const Vector3& End)
+inline float lcRayPointDistance(const lcVector3& Point, const lcVector3& Start, const lcVector3& End)
 {
-	Vector3 Dir = End - Start;
+	lcVector3 Dir = Point - Start;
+	lcVector3 RayDir = End - Start;
 
-	float t1 = Dot3(Start - Point, Dir);
-	float t2 = LengthSquared(Dir);
+	float t = lcDot(Dir, RayDir) / lcLengthSquared(RayDir);
+	t = lcClamp(t, 0.0f, 1.0f);
 
-	float t = -t1 / t2;
+	lcVector3 Closest = Start + t * RayDir;
 
-	if (t < 0.0f)
-		t = 0.0f;
-	else if (t > 1.0f)
-		t = 1.0f;
-
-	Vector3 Closest = Start + t * Dir;
-
-	return Length(Closest - Point);
+	return lcLength(Closest - Point);
 }
-*/
+
 // Returns true if the axis aligned box intersects the volume defined by planes.
 inline bool lcBoundingBoxIntersectsVolume(const lcVector3& Min, const lcVector3& Max, const lcVector4 Planes[6])
 {
@@ -1554,6 +1891,30 @@ inline bool lcBoundingBoxIntersectsVolume(const lcVector3& Min, const lcVector3&
 
 	return false;
 }
+
+struct lcBoundingBox
+{
+	lcVector3 Min;
+	lcVector3 Max;
+};
+
+inline void lcGetBoxCorners(const lcVector3& Min, const lcVector3& Max, lcVector3 Points[8])
+{
+	Points[0] = lcVector3(Max.x, Max.y, Min.z);
+	Points[1] = lcVector3(Min.x, Max.y, Min.z);
+	Points[2] = lcVector3(Max.x, Max.y, Max.z);
+	Points[3] = lcVector3(Min.x, Min.y, Min.z);
+	Points[4] = lcVector3(Min.x, Min.y, Max.z);
+	Points[5] = lcVector3(Max.x, Min.y, Max.z);
+	Points[6] = lcVector3(Max.x, Min.y, Min.z);
+	Points[7] = lcVector3(Min.x, Max.y, Max.z);
+}
+
+inline void lcGetBoxCorners(const lcBoundingBox& BoundingBox, lcVector3 Points[8])
+{
+	lcGetBoxCorners(BoundingBox.Min, BoundingBox.Max, Points);
+}
+
 /*
 bool SphereIntersectsVolume(const Vector3& Center, float Radius, const Vector4* Planes, int NumPlanes)
 {
