@@ -4,8 +4,7 @@
 enum LC_PROFILE_KEY
 {
 	// Settings.
-	LC_PROFILE_SNAP,
-	LC_PROFILE_ANGLE_SNAP,
+	LC_PROFILE_FIXED_AXES,
 	LC_PROFILE_LINE_WIDTH,
 	LC_PROFILE_LIGHTING_MODE,
 	LC_PROFILE_DRAW_AXES,
@@ -20,7 +19,8 @@ enum LC_PROFILE_KEY
 	LC_PROFILE_CHECK_UPDATES,
 	LC_PROFILE_PROJECTS_PATH,
 	LC_PROFILE_PARTS_LIBRARY,
-	LC_PROFILE_SHORTCUTS,
+	LC_PROFILE_KEYBOARD_SHORTCUTS,
+	LC_PROFILE_MOUSE_SHORTCUTS,
 	LC_PROFILE_CATEGORIES,
 	LC_PROFILE_RECENT_FILE1,
 	LC_PROFILE_RECENT_FILE2,
@@ -30,7 +30,7 @@ enum LC_PROFILE_KEY
 	LC_PROFILE_MOUSE_SENSITIVITY,
 	LC_PROFILE_IMAGE_WIDTH,
 	LC_PROFILE_IMAGE_HEIGHT,
-	LC_PROFILE_IMAGE_OPTIONS,
+	LC_PROFILE_IMAGE_EXTENSION,
 	LC_PROFILE_PRINT_ROWS,
 	LC_PROFILE_PRINT_COLUMNS,
 
@@ -69,6 +69,7 @@ enum LC_PROFILE_ENTRY_TYPE
 	LC_PROFILE_ENTRY_INT,
 	LC_PROFILE_ENTRY_FLOAT,
 	LC_PROFILE_ENTRY_STRING,
+	LC_PROFILE_ENTRY_STRINGLIST,
 	LC_PROFILE_ENTRY_BUFFER
 };
 
@@ -79,6 +80,7 @@ public:
 	lcProfileEntry(const char* Section, const char* Key, unsigned int DefaultValue);
 	lcProfileEntry(const char* Section, const char* Key, float DefaultValue);
 	lcProfileEntry(const char* Section, const char* Key, const char* DefaultValue);
+	lcProfileEntry(const char* Section, const char* Key, const QStringList& StringList);
 	lcProfileEntry(const char* Section, const char* Key);
 
 	LC_PROFILE_ENTRY_TYPE mType;
@@ -98,14 +100,20 @@ extern lcProfileEntry gProfileEntries[LC_NUM_PROFILE_KEYS];
 
 void lcRemoveProfileKey(LC_PROFILE_KEY Key);
 
+int lcGetDefaultProfileInt(LC_PROFILE_KEY Key);
+float lcGetDefaultProfileFloat(LC_PROFILE_KEY Key);
+QString lcGetDefaultProfileString(LC_PROFILE_KEY Key);
+
 int lcGetProfileInt(LC_PROFILE_KEY Key);
 float lcGetProfileFloat(LC_PROFILE_KEY Key);
-const char* lcGetProfileString(LC_PROFILE_KEY Key);
-void lcGetProfileBuffer(LC_PROFILE_KEY Key, lcMemFile& Buffer);
+QString lcGetProfileString(LC_PROFILE_KEY Key);
+QStringList lcGetProfileStringList(LC_PROFILE_KEY Key);
+QByteArray lcGetProfileBuffer(LC_PROFILE_KEY Key);
 
 void lcSetProfileInt(LC_PROFILE_KEY Key, int Value);
 void lcSetProfileFloat(LC_PROFILE_KEY Key, float Value);
-void lcSetProfileString(LC_PROFILE_KEY Key, const char* Value);
-void lcSetProfileBuffer(LC_PROFILE_KEY Key, const lcMemFile& Buffer);
+void lcSetProfileString(LC_PROFILE_KEY Key, const QString& Value);
+void lcSetProfileStringList(LC_PROFILE_KEY Key, const QStringList& Value);
+void lcSetProfileBuffer(LC_PROFILE_KEY Key, const QByteArray& Buffer);
 
 #endif // LC_PROFILE_H
