@@ -1,8 +1,6 @@
 #ifndef _LC_TEXTURE_H_
 #define _LC_TEXTURE_H_
 
-#include "opengl.h"
-
 #define LC_TEXTURE_WRAPU         0x01
 #define LC_TEXTURE_WRAPV         0x02
 #define LC_TEXTURE_MIPMAPS       0x04
@@ -25,6 +23,8 @@ public:
 	lcTexture();
 	~lcTexture();
 
+	void CreateGridTexture();
+
 	bool Load(const char* FileName, int Flags = 0);
 	bool Load(lcMemFile& File, int Flags = 0);
 	bool Load(Image& image, int Flags);
@@ -62,4 +62,9 @@ protected:
 	int mRefCount;
 };
 
+lcTexture* lcLoadTexture(const QString& FileName, int Flags);
+void lcReleaseTexture(lcTexture* Texture);
+
+extern lcTexture* gGridTexture;
+
 #endif // _LC_TEXTURE_H_
