@@ -38,6 +38,19 @@ bool lcZipFile::OpenRead(const char* FilePath)
 	return true;
 }
 
+bool lcZipFile::OpenRead(lcFile* File)
+{
+	mFile = File;
+
+	if (!Open())
+	{
+		mFile = NULL;
+		return false;
+	}
+
+	return true;
+}
+
 bool lcZipFile::OpenWrite(const char* FilePath, bool Append)
 {
 	lcDiskFile* File = new lcDiskFile();
@@ -78,7 +91,7 @@ lcuint64 lcZipFile::SearchCentralDir()
 	lcuint8 buf[CommentBufferSize + 4];
 
 	SizeFile = mFile->GetLength();
-	MaxBack = lcMin(SizeFile, 0xffffU);
+	MaxBack = lcMin(SizeFile, 0xffffULL);
 	BackRead = 4;
 	PosFound = 0;
 
@@ -121,7 +134,7 @@ lcuint64 lcZipFile::SearchCentralDir64()
 	lcuint8 buf[CommentBufferSize + 4];
 
 	SizeFile = mFile->GetLength();
-	MaxBack = lcMin(SizeFile, 0xffffU);
+	MaxBack = lcMin(SizeFile, 0xffffULL);
 	BackRead = 4;
 	PosFound = 0;
 
@@ -789,7 +802,7 @@ bool lcZipFile::AddFile(const char* FileName, lcMemFile& File)
 	Info.crc = Crc32;
 	Info.compressed_size = CompressedFile.GetLength();
 	Info.uncompressed_size = File.GetLength();
-	Info.size_filename = strlen(FileName);
+	Info.size_filename = (lcuint16)strlen(FileName);
 	Info.size_file_extra = 0;
 	Info.size_file_comment = 0;
 	Info.disk_num_start = 0;
