@@ -1,7 +1,7 @@
 #ifndef _LC_ZIPFILE_H_
 #define _LC_ZIPFILE_H_
 
-#include "array.h"
+#include "lc_array.h"
 
 #ifdef DeleteFile
 #undef DeleteFile
@@ -54,6 +54,7 @@ public:
 	~lcZipFile();
 
 	bool OpenRead(const char* FilePath);
+	bool OpenRead(lcFile* File);
 	bool OpenWrite(const char* FilePath, bool Append);
 
 	bool ExtractFile(int FileIndex, lcMemFile& File, lcuint32 MaxLength = 0xffffffff);
@@ -61,7 +62,7 @@ public:
 	bool AddFile(const char* FileName, lcMemFile& File);
 	bool DeleteFile(const char* FileName);
 
-	ObjArray<lcZipFileInfo> mFiles;
+	lcArray<lcZipFileInfo> mFiles;
 
 protected:
 	bool Open();
@@ -71,7 +72,7 @@ protected:
 	lcuint64 SearchCentralDir64();
 	bool CheckFileCoherencyHeader(int FileIndex, lcuint32* SizeVar, lcuint64* OffsetLocalExtraField, lcuint32* SizeLocalExtraField);
 
-	lcDiskFile* mFile;
+	lcFile* mFile;
 
 	bool mModified;
 	bool mZip64;
