@@ -3,9 +3,7 @@
 
 #include "lc_glwidget.h"
 #include "lc_math.h"
-#include "array.h"
-
-class PieceInfo;
+#include "lc_array.h"
 
 enum LC_MFW_TYPES
 {
@@ -47,10 +45,10 @@ struct lcMinifig
 class MinifigWizard : public lcGLWidget
 {
 public:
-	MinifigWizard(lcMinifig* Minifig);
-	~MinifigWizard ();
+	MinifigWizard();
+	~MinifigWizard();
 
-	void OnDraw ();
+	void OnDraw();
 	void OnLeftButtonDown();
 	void OnLeftButtonUp();
 	void OnLeftButtonDoubleClick();
@@ -67,18 +65,18 @@ public:
 
 	void ParseSettings(lcFile& Settings);
 
-	ObjArray<lcMinifigPieceInfo> mSettings[LC_MFW_NUMITEMS];
+	lcArray<lcMinifigPieceInfo> mSettings[LC_MFW_NUMITEMS];
 
-	lcMinifig* mMinifig;
+	lcMinifig mMinifig;
 
-	int m_Tracking;
-	int m_DownX;
-	int m_DownY;
+	int mTracking;
+	int mDownX;
+	int mDownY;
 
-	float m_Distance;
-	float m_RotateX;
-	float m_RotateZ;
-	bool m_AutoZoom;
+	float mDistance;
+	float mRotateX;
+	float mRotateZ;
+	bool mAutoZoom;
 };
 
 #endif // _MINIFIG_H_
