@@ -13,7 +13,7 @@ public:
 	{ m_pData = NULL; *this = str; }
 	~String();
 
-	int GetLength() const
+	size_t GetLength() const
 	{ return strlen(m_pData); }
 	bool IsEmpty() const
 	{ return m_pData[0] == '\0'; }
@@ -48,15 +48,12 @@ public:
 
 	// simple sub-string extraction
 	String& Mid(int first, int count) const;
-	String& Mid(int first) const
-	{ return Mid(first, GetLength() - first); }
 	String& Left(int count) const;
 	String& Right(int count) const;
 
 	// upper/lower/reverse conversion
 	void MakeUpper();
 	void MakeLower();
-	void MakeReverse();
 
 	// trimming whitespace (either side)
 	void TrimRight();
@@ -92,6 +89,11 @@ public:
 		return m_pData;
 	}
 
+	const char* Buffer() const
+	{
+		return m_pData;
+	}
+
 	char* GetBuffer(int len)
 	{
 		if (len > (int)strlen(m_pData))
@@ -103,12 +105,6 @@ public:
 		}
 		return m_pData;
 	}
-	void ReleaseBuffer(int len = -1)
-	{
-		if (len == -1)
-			len = strlen(m_pData);
-		m_pData[len] = '\0';
-	}
 
 protected:
 	char* m_pData;
