@@ -1,6 +1,7 @@
 #include "lc_global.h"
 #include <string.h>
 #include "texfont.h"
+#include "lc_context.h"
 
 static const unsigned char TextureData[2048] =
 {
@@ -88,24 +89,29 @@ static const unsigned char GlyphData[] =
 
 // ============================================================================
 
+TexFont gTexFont;
+
 TexFont::TexFont()
 {
+	mRefCount = 0;
 	mTexture = 0;
 	memset(&mGlyphs, 0, sizeof(mGlyphs));
 }
 
 TexFont::~TexFont()
 {
-	glDeleteTextures(1, &mTexture);
 }
 
-bool TexFont::Initialize()
+bool TexFont::Load()
 {
+	mRefCount++;
+
+	if (mRefCount != 1)
+		return true;
+
 	mFontHeight = 16;
 
-	if (mTexture == 0)
-		glGenTextures(1, &mTexture);
-
+	glGenTextures(1, &mTexture);
 	glBindTexture(GL_TEXTURE_2D, mTexture);
 	glDisable(GL_TEXTURE_GEN_S);
 	glDisable(GL_TEXTURE_GEN_T);
@@ -115,14 +121,17 @@ bool TexFont::Initialize()
 	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
 	glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
 
-	unsigned char ExpandedData[sizeof(TextureData) * 8];
+	unsigned char ExpandedData[sizeof(TextureData) * 8 * 2];
 	for (unsigned int TexelIdx = 0; TexelIdx < sizeof(TextureData) * 8; TexelIdx++)
-		ExpandedData[TexelIdx] = TextureData[TexelIdx / 8] & (1 << (TexelIdx % 8)) ? 255 : 0;
+	{
+		unsigned char Texel = TextureData[TexelIdx / 8] & (1 << (TexelIdx % 8)) ? 255 : 0;
+		ExpandedData[TexelIdx * 2] = ExpandedData[TexelIdx * 2 + 1] = Texel;
+	}
 
 	mTextureWidth = 128;
 	mTextureHeight = 128;
 
-	glTexImage2D(GL_TEXTURE_2D, 0, GL_ALPHA, mTextureWidth, mTextureHeight, 0, GL_ALPHA, GL_UNSIGNED_BYTE, ExpandedData);
+	glTexImage2D(GL_TEXTURE_2D, 0, GL_LUMINANCE_ALPHA, mTextureWidth, mTextureHeight, 0, GL_LUMINANCE_ALPHA, GL_UNSIGNED_BYTE, ExpandedData);
 
 	const unsigned char* Ptr = GlyphData;
 
@@ -148,6 +157,16 @@ bool TexFont::Initialize()
 	return true;
 }
 
+void TexFont::Release()
+{
+	mRefCount--;
+	if (mRefCount == 0)
+	{
+		glDeleteTextures(1, &mTexture);
+		mTexture = 0;
+	}
+}
+
 void TexFont::GetStringDimensions(int* cx, int* cy, const char* Text) const
 {
 	*cx = 0;
@@ -160,9 +179,9 @@ void TexFont::GetStringDimensions(int* cx, int* cy, const char* Text) const
 	}
 }
 
-void TexFont::PrintText(float Left, float Top, float Z, const char* Text) const
+void TexFont::PrintText(lcContext* Context, float Left, float Top, float Z, const char* Text) const
 {
-	int Length = strlen(Text);
+	size_t Length = strlen(Text);
 
 	if (!Length)
 		return;
@@ -202,13 +221,42 @@ void TexFont::PrintText(float Left, float Top, float Z, const char* Text) const
 		Text++;
 	}
 
-	glVertexPointer(3, GL_FLOAT, 5 * sizeof(float), Verts);
-	glEnableClientState(GL_TEXTURE_COORD_ARRAY);
-	glTexCoordPointer(2, GL_FLOAT, 5 * sizeof(float), Verts + 3);
+	Context->SetVertexBufferPointer(Verts);
+	Context->SetVertexFormat(0, 3, 2, 0);
 
-	glDrawArrays(GL_QUADS, 0, 4 * Length);
+	Context->DrawPrimitives(GL_QUADS, 0, 4 * (GLsizei)Length);
 
-	glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+	Context->ClearVertexBuffer(); // context remove
 
 	delete[] Verts;
 }
+
+void TexFont::GetGlyphQuad(float Left, float Top, float Z, int Glyph, float* Buffer) const
+{
+	Left -= mGlyphs[Glyph].width / 2.0f;
+	Top += mFontHeight / 2.0f;
+
+	*Buffer++ = Left;
+	*Buffer++ = Top;
+	*Buffer++ = Z;
+	*Buffer++ = mGlyphs[Glyph].left;
+	*Buffer++ = mGlyphs[Glyph].top;
+
+	*Buffer++ = Left;
+	*Buffer++ = Top - mFontHeight;
+	*Buffer++ = Z;
+	*Buffer++ = mGlyphs[Glyph].left;
+	*Buffer++ = mGlyphs[Glyph].bottom;
+
+	*Buffer++ = Left + mGlyphs[Glyph].width;
+	*Buffer++ = Top - mFontHeight;
+	*Buffer++ = Z;
+	*Buffer++ = mGlyphs[Glyph].right;
+	*Buffer++ = mGlyphs[Glyph].bottom;
+
+	*Buffer++ = Left + mGlyphs[Glyph].width;
+	*Buffer++ = Top;
+	*Buffer++ = Z;
+	*Buffer++ = mGlyphs[Glyph].right;
+	*Buffer++ = mGlyphs[Glyph].top;
+}
