@@ -6,6 +6,7 @@
 #include "lc_basewindow.h"
 #include "lc_library.h"
 #include "lc_application.h"
+#include "lc_qutils.h"
 #include "pieceinf.h"
 
 lcQPreferencesDialog::lcQPreferencesDialog(QWidget *parent, void *data) :
@@ -41,7 +42,7 @@ lcQPreferencesDialog::lcQPreferencesDialog(QWidget *parent, void *data) :
 	else
 		ui->antiAliasingSamples->setCurrentIndex(0);
 	ui->edgeLines->setChecked(options->Preferences.mDrawEdgeLines);
-	ui->lineWidth->setText(QString::number(options->Preferences.mLineWidth));
+	ui->lineWidth->setText(lcFormatValueLocalized(options->Preferences.mLineWidth));
 	ui->gridStuds->setChecked(options->Preferences.mDrawGridStuds);
 	ui->gridLines->setChecked(options->Preferences.mDrawGridLines);
 	ui->gridLineSpacing->setText(QString::number(options->Preferences.mGridLineSpacing));
@@ -106,7 +107,7 @@ void lcQPreferencesDialog::accept()
 		options->AASamples = 2;
 
 	options->Preferences.mDrawEdgeLines = ui->edgeLines->isChecked();
-	options->Preferences.mLineWidth = ui->lineWidth->text().toFloat();
+	options->Preferences.mLineWidth = lcParseValueLocalized(ui->lineWidth->text());
 
 	options->Preferences.mDrawGridStuds = ui->gridStuds->isChecked();
 	options->Preferences.mDrawGridLines = ui->gridLines->isChecked();
@@ -440,7 +441,7 @@ void lcQPreferencesDialog::updateCommandList()
 
 	for (int actionIdx = 0; actionIdx < LC_NUM_COMMANDS; actionIdx++)
 	{
-		const QString identifier = gCommands[actionIdx].ID;
+		const QString identifier = tr(gCommands[actionIdx].ID);
 
 		int pos = identifier.indexOf(QLatin1Char('.'));
 		int subPos = identifier.indexOf(QLatin1Char('.'), pos + 1);
@@ -633,7 +634,7 @@ void lcQPreferencesDialog::UpdateMouseTreeItem(int ItemIndex)
 	if (Item)
 		Item->setText(1, Shortcut);
 	else
-		new QTreeWidgetItem(ui->mouseTree, QStringList() << gToolNames[ItemIndex] << Shortcut);
+		new QTreeWidgetItem(ui->mouseTree, QStringList() << tr(gToolNames[ItemIndex]) << Shortcut);
 }
 
 void lcQPreferencesDialog::on_mouseAssign_clicked()
@@ -677,7 +678,7 @@ void lcQPreferencesDialog::on_mouseAssign_clicked()
 		{
 			if (ToolIdx != ButtonIndex && options->MouseShortcuts.mShortcuts[ToolIdx].Button == Button && options->MouseShortcuts.mShortcuts[ToolIdx].Modifiers == Modifiers)
 			{
-				if (QMessageBox::question(this, tr("Override Shortcut"), tr("This shortcut is already assigned to '%1', do you want to replace it?").arg(gToolNames[ToolIdx]), QMessageBox::Yes | QMessageBox::No) == QMessageBox::No)
+				if (QMessageBox::question(this, tr("Override Shortcut"), tr("This shortcut is already assigned to '%1', do you want to replace it?").arg(tr(gToolNames[ToolIdx])), QMessageBox::Yes | QMessageBox::No) == QMessageBox::No)
 					return;
 
 				options->MouseShortcuts.mShortcuts[ToolIdx].Button = Qt::NoButton;
