@@ -29,9 +29,13 @@ public slots:
 	void accept();
 	void on_projectsFolderBrowse_clicked();
 	void on_partsLibraryBrowse_clicked();
+	void on_povrayExecutableBrowse_clicked();
+	void on_lgeoPathBrowse_clicked();
+	void colorClicked();
 	void on_antiAliasing_toggled();
 	void on_edgeLines_toggled();
-	void on_baseGrid_toggled();
+	void on_gridStuds_toggled();
+	void on_gridLines_toggled();
 	void updateParts();
 	void on_newCategory_clicked();
 	void on_editCategory_clicked();
@@ -45,12 +49,18 @@ public slots:
 	void on_shortcutsExport_clicked();
 	void on_shortcutsReset_clicked();
 	void commandChanged(QTreeWidgetItem *current);
+	void on_mouseAssign_clicked();
+	void on_mouseRemove_clicked();
+	void on_mouseReset_clicked();
+	void MouseTreeItemChanged(QTreeWidgetItem* Current);
 
 private:
 	Ui::lcQPreferencesDialog *ui;
 
 	void updateCategories();
 	void updateCommandList();
+	void UpdateMouseTree();
+	void UpdateMouseTreeItem(int ItemIndex);
 	void setShortcutModified(QTreeWidgetItem *treeItem, bool modified);
 };
 
