@@ -15,14 +15,15 @@ class lcQUpdateDialog : public QDialog
 	Q_OBJECT
 	
 public:
-	explicit lcQUpdateDialog(QWidget *parent, void *data);
+	explicit lcQUpdateDialog(QWidget* Parent, bool InitialUpdate);
 	~lcQUpdateDialog();
 
 	void parseUpdate(const char *update);
 
 public slots:
 	void replyFinished(QNetworkReply *reply);
-	void cancel();
+	void accept();
+	void reject();
 	void finished(int result);
 
 private:
@@ -30,7 +31,8 @@ private:
 
 	QNetworkReply *updateReply;
 	QNetworkAccessManager *manager;
-	bool initialUpdate;
+	QByteArray versionData;
+	bool mInitialUpdate;
 };
 
 #endif // LC_QUPDATEDIALOG_H
